==> admost_flutter_plugin-1.1.0.tar.gz: lib/admost_banner.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'admost_banner_controller.dart';
import 'admost_banner_size.dart';
import 'admost_ad_events.dart';

class AdmostBanner extends StatefulWidget {
  final String adUnitId;
  final AdmostBannerSize adSize;
  final void Function(AdmostAdEvent, Map<String, dynamic>) listener;
  final void Function(AdmostBannerController) onBannerCreated;

  AdmostBanner({
    Key key,
    @required this.adUnitId,
    @required this.adSize,
    this.listener,
    this.onBannerCreated,
  }) : super(key: key) {
    if(adUnitId == null || adSize == null) {
      print("adUnitId or adSize cannot be null!");
    }
  }

  @override
  _AdmostBannerState createState() => _AdmostBannerState();
}

class _AdmostBannerState extends State<AdmostBanner> {
  AdmostBannerController _controller;

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Container(
        width: widget.adSize.width >= 0
            ? widget.adSize.width.toDouble()
            : double.infinity,
        height: widget.adSize.height >= 0
            ? widget.adSize.height.toDouble()
            : double.infinity,
        child: AndroidView(
          key: UniqueKey(),
          viewType: 'admost_flutter/banner',
          creationParams: <String, dynamic>{
            "adUnitId": widget.adUnitId,
            "adSize": widget.adSize.toMap,
            'isNativeAd': 'false',
          },
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      return Container(
        key: UniqueKey(),
        width: widget.adSize.width.toDouble(),
        height: widget.adSize.height.toDouble(),
        child: UiKitView(
          viewType: 'admost_flutter/banner',
          creationParams: <String, dynamic>{
            "adUnitId": widget.adUnitId,
            "adSize": widget.adSize.toMap,
            'isNativeAd': 'false',
          },
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else {
      return Text('$defaultTargetPlatform is not yet supported by the plugin');
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  void _onPlatformViewCreated(int id) {
    _controller = AdmostBannerController(id, widget.listener);

    if (widget.onBannerCreated != null) {
      widget.onBannerCreated(_controller);
    }
  }
}

==> admost_flutter_plugin-1.2.5.tar.gz: lib/admost_banner.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'admost_banner_controller.dart';
import 'admost_banner_size.dart';
import 'admost_ad_events.dart';

class AdmostBanner extends StatefulWidget {
  final String adUnitId;
  final AdmostBannerSize adSize;
  final String? tag;
  final void Function(AdmostAdEvent, Map<String, dynamic>)? listener;
  final void Function(AdmostBannerController?)? onBannerCreated;

  AdmostBanner({
    Key? key,
    required this.adUnitId,
    required this.adSize,
    this.listener,
    this.onBannerCreated,
    this.tag
  }) : super(key: key) {
    if(adUnitId == null || adSize == null) {
      print("adUnitId or adSize cannot be null!");
    }
  }

  @override
  _AdmostBannerState createState() => _AdmostBannerState();
}

class _AdmostBannerState extends State<AdmostBanner> {
  AdmostBannerController? _controller;

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Container(
        width: widget.adSize.width >= 0
            ? widget.adSize.width.toDouble()
            : double.infinity,
        height: widget.adSize.height >= 0
            ? widget.adSize.height.toDouble()
            : double.infinity,
        child: AndroidView(
          key: UniqueKey(),
          viewType: 'admost_flutter/banner',
          creationParams: <String, dynamic>{
            "adUnitId": widget.adUnitId,
            "adSize": widget.adSize.toMap,
            'isNativeAd': 'false',
            "tag":widget.tag
          },
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      return Container(
        key: UniqueKey(),
        width: widget.adSize.width.toDouble(),
        height: widget.adSize.height.toDouble(),
        child: UiKitView(
          viewType: 'admost_flutter/banner',
          creationParams: <String, dynamic>{
            "adUnitId": widget.adUnitId,
            "adSize": widget.adSize.toMap,
            'isNativeAd': 'false',
            "tag":widget.tag
          },
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else {
      return Text('$defaultTargetPlatform is not yet supported by the plugin');
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  void _onPlatformViewCreated(int id) {
    _controller = AdmostBannerController(id, widget.listener);

    if (widget.onBannerCreated != null) {
      widget.onBannerCreated!(_controller);
    }
  }
}
